==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lximage-qt/lximage-qt_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="89"/>
        <source>Take a screenshot</source>
        <translation>خُذ لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="93"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[الملفّ1، الملفّ2،...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="148"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="149"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>صور لكسكيوت - عارض صور بسيط وسريع

الحقوق محفوظة © 2013
مشروع لكسدي: http://lxde.org/ ‎

المؤلّفون:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="242"/>
        <source>Open File</source>
        <translation>افتح ملفًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Image files (%1)</source>
        <translation>ملفّات الصّور (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Save File</source>
        <translation>احفظ الملفّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="530"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (يحمّل...) - عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="535"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (فشل التّحميل) - عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2×%3) - عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="576"/>
        <source>[*]Image Viewer</source>
        <translation>[*]عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="819"/>
        <source>Thumbnails</source>
        <translation>المصغّرات</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="159"/>
        <source>&amp;About</source>
        <translation>&amp;عن</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="169"/>
        <source>&amp;Open File</source>
        <translation>ا&amp;فتح ملفًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>&amp;Save</source>
        <translation>ا&amp;حفظ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="195"/>
        <source>Save &amp;As</source>
        <translation>احفظ &amp;ك‍</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="208"/>
        <source>&amp;Close</source>
        <translation>أ&amp;غلق</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="221"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;قرّب</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="234"/>
        <source>Zoom &amp;Out</source>
        <translation>ب&amp;عّد</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="247"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>ا&amp;نسخ إلى الحافظة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="257"/>
        <location filename="../../mainwindow.ui" line="260"/>
        <source>Next File</source>
        <translation>الملفّ التّالي</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="273"/>
        <location filename="../../mainwindow.ui" line="276"/>
        <source>Previous File</source>
        <translation>الملفّ السّابق</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Original Size</source>
        <translation>الحجم الأصليّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="299"/>
        <source>&amp;Fit</source>
        <translation>لا&amp;ئم</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="309"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;دوّر مع عقارب السّاعة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="319"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>دوّر عكس ع&amp;قارب السّاعة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="324"/>
        <source>P&amp;references</source>
        <translation>التّف&amp;ضيلات</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="329"/>
        <source>&amp;Print</source>
        <translation>ا&amp;طبع</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="332"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="342"/>
        <source>First File</source>
        <translation>الملفّ الأوّل</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="345"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="355"/>
        <source>Last File</source>
        <translation>الملف الأخير</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="358"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="368"/>
        <source>&amp;New Window</source>
        <translation>نافذة &amp;جديدة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="376"/>
        <source>Flip &amp;Horizontally</source>
        <translation>اقلب أ&amp;فقيًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="386"/>
        <source>Capture Screenshot</source>
        <translation>التقط لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="394"/>
        <source>F&amp;ull Screen</source>
        <translation>ملء ال&amp;شّاشة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="402"/>
        <source>Flip &amp;Vertically</source>
        <translation>اقلب &amp;رأسيًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="412"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>أل&amp;صق من الحافظة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="425"/>
        <source>&amp;Slide Show</source>
        <translation>عر&amp;ض شرائح</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="435"/>
        <source>&amp;Delete</source>
        <translation>اح&amp;ذف</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="438"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="446"/>
        <source>Show Thumbnails</source>
        <translation>أظهر المصغّرات</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="451"/>
        <source>File Properties</source>
        <translation>خصائص الملفّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;ملفّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>&amp;Help</source>
        <translation>م&amp;ساعدة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="77"/>
        <source>Go</source>
        <translation>انتقال</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="86"/>
        <source>&amp;View</source>
        <translation>من&amp;ظور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="100"/>
        <source>&amp;Edit</source>
        <translation>&amp;تحرير</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>Toolbar</source>
        <translation>شريط الأدوات</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>التّفضيلات</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>سمة الأيقونات:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>لون الخلفيّة في الوضع العاديّ:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>لون الخلفيّة في وضع ملء الشّاشة:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>فترة عرض الشّرائح (بالثّواني):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>عامّ</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="28"/>
        <source>Take a screenshot</source>
        <translation>خُذ لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="35"/>
        <source>Region</source>
        <translation>المنطقة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="41"/>
        <source>Whole screen</source>
        <translation>كامل الشّاشة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="51"/>
        <source>Current window only</source>
        <translation>النّافذة الحاليّة فقط</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="61"/>
        <source>Include mouse cursor</source>
        <translation>ضمّن مؤشّر الفأرة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="68"/>
        <source> seconds</source>
        <translation> ث</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="85"/>
        <source>Delay:</source>
        <translation>التّأخير:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="95"/>
        <source>Include window title and frame</source>
        <translation>ضمّن عنوان النّافذة وإطارها</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lximage-qt/lximage-qt_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>خُذ لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="98"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[الملفّ1، الملفّ2،...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../../upload/imageshackupload.cpp" line="49"/>
        <source>unknown error response</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../../upload/imgurupload.cpp" line="46"/>
        <source>unknown error response</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="145"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="146"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>صور لكسكيوت - عارض صور بسيط وسريع

الحقوق محفوظة © 2013
مشروع لكسدي: https://lxqt.org/ ‎

المؤلّفون:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="255"/>
        <source>Open File</source>
        <translation>افتح ملفًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="256"/>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Image files (%1)</source>
        <translation>ملفّات الصّور (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Open directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Save File</source>
        <translation>احفظ الملفّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (يحمّل...) - عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="544"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (فشل التّحميل) - عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2×%3) - عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="584"/>
        <source>[*]Image Viewer</source>
        <translation>[*]عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="851"/>
        <source>Thumbnails</source>
        <translation>المصغّرات</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="48"/>
        <source>ImageShack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="124"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="127"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="130"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="137"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>عارض الصّور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="162"/>
        <source>&amp;About</source>
        <translation>&amp;عن</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>&amp;Open File</source>
        <translation>ا&amp;فتح ملفًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="175"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&amp;Save</source>
        <translation>ا&amp;حفظ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="188"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Save &amp;As</source>
        <translation>احفظ &amp;ك‍</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="201"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>&amp;Close</source>
        <translation>أ&amp;غلق</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;قرّب</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="227"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Zoom &amp;Out</source>
        <translation>ب&amp;عّد</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="240"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>ا&amp;نسخ إلى الحافظة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="260"/>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>Next File</source>
        <translation>الملفّ التّالي</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="266"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="276"/>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Previous File</source>
        <translation>الملفّ السّابق</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="282"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Original Size</source>
        <translation>الحجم الأصليّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="295"/>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="305"/>
        <source>&amp;Fit</source>
        <translation>لا&amp;ئم</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="315"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;دوّر مع عقارب السّاعة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>دوّر عكس ع&amp;قارب السّاعة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="330"/>
        <source>P&amp;references</source>
        <translation>التّف&amp;ضيلات</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>&amp;Print</source>
        <translation>ا&amp;طبع</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="338"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>First File</source>
        <translation>الملفّ الأوّل</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>Last File</source>
        <translation>الملف الأخير</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="364"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>&amp;New Window</source>
        <translation>نافذة &amp;جديدة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="377"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="382"/>
        <source>Flip &amp;Horizontally</source>
        <translation>اقلب أ&amp;فقيًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="392"/>
        <source>Capture Screenshot</source>
        <translation>التقط لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F&amp;ull Screen</source>
        <translation>ملء ال&amp;شّاشة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="403"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="408"/>
        <source>Flip &amp;Vertically</source>
        <translation>اقلب &amp;رأسيًّا</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="418"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>أل&amp;صق من الحافظة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="431"/>
        <source>&amp;Slide Show</source>
        <translation>عر&amp;ض شرائح</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>&amp;Delete</source>
        <translation>اح&amp;ذف</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="444"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="452"/>
        <source>Show Thumbnails</source>
        <translation>أظهر المصغّرات</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="457"/>
        <source>File Properties</source>
        <translation>خصائص الملفّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="465"/>
        <source>Open &amp;Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="468"/>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="476"/>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="479"/>
        <source>Upload the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;ملفّ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>م&amp;ساعدة</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>انتقال</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>من&amp;ظور</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;تحرير</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="123"/>
        <source>Toolbar</source>
        <translation>شريط الأدوات</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>التّفضيلات</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>سمة الأيقونات:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>لون الخلفيّة في الوضع العاديّ:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>لون الخلفيّة في وضع ملء الشّاشة:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>فترة عرض الشّرائح (بالثّواني):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>عامّ</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>خُذ لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>المنطقة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>كامل الشّاشة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>النّافذة الحاليّة فقط</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>ضمّن مؤشّر الفأرة</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> ث</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>التّأخير:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>ضمّن عنوان النّافذة وإطارها</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
